@@ -1,25 +1,11 @@
 /*
-    Copyright 2008,2011 Will Stephenson <wstephenson@kde.org>
-    Copyright 2010 Lamarque Souza <lamarque@kde.org>
-    Copyright 2013 Daniel Nicoletti <dantti12@gmail.com>
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
-    Copyright 2013-2015 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2008, 2011 Will Stephenson <wstephenson@kde.org>
+    SPDX-FileCopyrightText: 2010 Lamarque Souza <lamarque@kde.org>
+    SPDX-FileCopyrightText: 2013 Daniel Nicoletti <dantti12@gmail.com>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2013-2015 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "modem.h"
@@ -34,7 +20,6 @@
 #include "generictypes_p.h"
 #include "mmdebug_p.h"
 
-#include <QDomDocument>
 
 namespace ModemManager
 {
@@ -575,6 +560,18 @@ ModemManager::Bearer::Ptr ModemManager::ModemPrivate::findRegisteredBearer(const
     return ret;
 }
 
+void ModemManager::Modem::setTimeout(int timeout)
+{
+    Q_D(Modem);
+    d->modemIface.setTimeout(timeout);
+}
+
+int ModemManager::Modem::timeout() const
+{
+    Q_D(const Modem);
+    return d->modemIface.timeout();
+}
+
 void ModemManager::ModemPrivate::onPropertiesChanged(const QString &ifaceName, const QVariantMap &changedProps, const QStringList &invalidatedProps)
 {
     Q_UNUSED(invalidatedProps);
